---
name: Bug report
about: Create a report to help us improve CogniWall
title: "[BUG] "
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Initialize CogniWall config '...'
2. Run pipeline '...'
3. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment (please complete the following information):**
 - OS: [e.g. iOS]
 - Python version: [e.g. 3.10]
 - CogniWall version: [e.g. 0.1.0]

**Additional context**
Add any other context about the problem here.
